@@ -18,7 +18,7 @@ test_that("catalog drops some chunk", {
 test_that("catalog engine returns a valid output", {
 
   ctg@chunk_options$drop = 1:3
-  m = grid_metrics(ctg, ~mean(Z), 20)
+  m = pixel_metrics(ctg, ~mean(Z), 20)
 
   expect_equivalent(st_bbox(m), st_bbox(c(xmin = 0, xmax = 100,ymin = 60,ymax = 200)))
   expect_equal(sum(is.na(m[])), 9)
